@@ -17,9 +17,9 @@ __all__ = ['encode', 'decode', 'DecodeError']
 class DecodeError(Exception): pass
 
 signing_methods = {
-    'HS256': lambda msg, key: hmac.new(key, msg, hashlib.sha256).hexdigest(),
-    'HS384': lambda msg, key: hmac.new(key, msg, hashlib.sha384).hexdigest(),
-    'HS512': lambda msg, key: hmac.new(key, msg, hashlib.sha512).hexdigest(),
+    'HS256': lambda msg, key: hmac.new(key, msg, hashlib.sha256).digest(),
+    'HS384': lambda msg, key: hmac.new(key, msg, hashlib.sha384).digest(),
+    'HS512': lambda msg, key: hmac.new(key, msg, hashlib.sha512).digest(),
 }
 
 def base64url_decode(input):
@@ -36,7 +36,8 @@ def encode(payload, key, algorithm='HS256'):
     segments.append(base64url_encode(json.dumps(payload)))
     signing_input = '.'.join(segments)
     try:
-        signature = signing_methods[algorithm](signing_input, key)
+        ascii_key = unicode(key).encode('utf8')
+        signature = signing_methods[algorithm](signing_input, ascii_key)
     except KeyError:
         raise NotImplementedError("Algorithm not supported")
     segments.append(base64url_encode(signature))
@@ -56,7 +57,8 @@ def decode(jwt, key='', verify=True):
         raise DecodeError("Invalid segment encoding")
     if verify:
         try:
-            if not signature == signing_methods[header['alg']](signing_input, key):
+            ascii_key = unicode(key).encode('utf8')
+            if not signature == signing_methods[header['alg']](signing_input, ascii_key):
                 raise DecodeError("Signature verification failed")
         except KeyError:
             raise DecodeError("Algorithm not supported")
